==> react-web-foundation-0.1.1.tgz: package/es/Text/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import { any, array, bool, func, number, object, oneOf, oneOfType, string } from "prop-types";
import { Component } from "react";
import createElement, { ElementPropTypes } from "../createElement";
import StyleSheet from "../StyleSheet";

var Text = (_temp = _class = function (_Component) {
  _inherits(Text, _Component);

  function Text() {
    _classCallCheck(this, Text);

    return _possibleConstructorReturn(this, _Component.apply(this, arguments));
  }

  Text.prototype.getChildContext = function getChildContext() {
    return { isInAParentText: true };
  };

  Text.prototype.render = function render() {
    var _props = this.props,
        dir = _props.dir,
        numberOfLines = _props.numberOfLines,
        onPress = _props.onPress,
        selectable = _props.selectable,
        style = _props.style,
        otherProps = _objectWithoutProperties(_props, ["dir", "numberOfLines", "onPress", "selectable", "style"]);

    var isInAParentText = this.context.isInAParentText;


    if (onPress) {
      otherProps.accessible = true;
      otherProps.onClick = onPress;
      otherProps.onKeyDown = this._createEnterHandler(onPress);
    }

    // allow browsers to automatically infer the language writing direction
    otherProps.dir = dir !== undefined ? dir : "auto";
    otherProps.style = [styles.initial, this.context.isInAParentText === true && styles.isInAParentText, style, selectable === false && styles.notSelectable, numberOfLines === 1 && styles.singleLineStyle, onPress && styles.pressable];

    var component = isInAParentText ? "span" : "div";

    return createElement(component, otherProps);
  };

  Text.prototype._createEnterHandler = function _createEnterHandler(fn) {
    return function (e) {
      if (e.keyCode === 13) {
        fn && fn(e);
      }
    };
  };

  return Text;
}(Component), _class.displayName = "Text", _class.childContextTypes = {
  isInAParentText: bool
}, _class.contextTypes = {
  isInAParentText: bool
}, _temp);
Text.propTypes = process.env.NODE_ENV !== "production" ? _extends({}, ElementPropTypes, {
  accessibilityRole: oneOf(["button", "heading", "label", "link", "listitem"]),
  numberOfLines: number,
  onPress: func,
  selectable: bool
}) : {};


var styles = StyleSheet.create({
  initial: {
    borderWidth: 0,
    boxSizing: "border-box",
    color: "inherit",
    display: "inline",
    font: "inherit",
    fontFamily: "System",
    fontSize: 14,
    margin: 0,
    padding: 0,
    textDecorationLine: "none",
    whiteSpace: "pre-wrap",
    wordWrap: "break-word"
  },
  isInAParentText: {
    // inherit parent font styles
    fontFamily: "inherit",
    fontSize: "inherit",
    whiteSpace: "inherit"
  },
  notSelectable: {
    userSelect: "none"
  },
  pressable: {
    cursor: "pointer"
  },
  singleLineStyle: {
    maxWidth: "100%",
    overflow: "hidden",
    textOverflow: "ellipsis",
    whiteSpace: "nowrap"
  }
});

export default Text;

==> react-web-foundation-0.1.4.tgz: package/es/Text/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import { any, array, bool, func, number, object, oneOf, oneOfType, string } from "prop-types";
import { Component } from "react";
import createElement, { ElementPropTypes } from "../createElement";
import StyleSheet from "../StyleSheet";

var Text = (_temp = _class = function (_Component) {
  _inherits(Text, _Component);

  function Text() {
    _classCallCheck(this, Text);

    return _possibleConstructorReturn(this, _Component.apply(this, arguments));
  }

  Text.prototype.getChildContext = function getChildContext() {
    return { isInAParentText: true };
  };

  Text.prototype.render = function render() {
    var _props = this.props,
        dir = _props.dir,
        numberOfLines = _props.numberOfLines,
        onPress = _props.onPress,
        selectable = _props.selectable,
        style = _props.style,
        otherProps = _objectWithoutProperties(_props, ["dir", "numberOfLines", "onPress", "selectable", "style"]);

    var isInAParentText = this.context.isInAParentText;


    if (onPress) {
      otherProps.accessible = true;
      otherProps.onClick = onPress;
      otherProps.onKeyDown = this._createEnterHandler(onPress);
    }

    // allow browsers to automatically infer the language writing direction
    otherProps.dir = dir !== undefined ? dir : "auto";
    otherProps.style = [styles.initial, this.context.isInAParentText === true && styles.isInAParentText, style, selectable === false && styles.notSelectable, numberOfLines === 1 && styles.singleLineStyle, onPress && styles.pressable];

    var component = isInAParentText ? "span" : "div";

    return createElement(component, otherProps);
  };

  Text.prototype._createEnterHandler = function _createEnterHandler(fn) {
    return function (e) {
      if (e.keyCode === 13) {
        fn && fn(e);
      }
    };
  };

  return Text;
}(Component), _class.displayName = "Text", _class.propTypes = _extends({}, ElementPropTypes, {
  accessibilityRole: oneOf(["button", "heading", "label", "link", "listitem"]),
  numberOfLines: number,
  onPress: func,
  selectable: bool
}), _class.childContextTypes = {
  isInAParentText: bool
}, _class.contextTypes = {
  isInAParentText: bool
}, _temp);


var styles = StyleSheet.create({
  initial: {
    borderWidth: 0,
    boxSizing: "border-box",
    color: "inherit",
    display: "inline",
    font: "inherit",
    fontFamily: "System",
    fontSize: 14,
    margin: 0,
    padding: 0,
    textDecorationLine: "none",
    whiteSpace: "pre-wrap",
    wordWrap: "break-word"
  },
  isInAParentText: {
    // inherit parent font styles
    fontFamily: "inherit",
    fontSize: "inherit",
    whiteSpace: "inherit"
  },
  notSelectable: {
    userSelect: "none"
  },
  pressable: {
    cursor: "pointer"
  },
  singleLineStyle: {
    maxWidth: "100%",
    overflow: "hidden",
    textOverflow: "ellipsis",
    whiteSpace: "nowrap"
  }
});

export default Text;
